@@ -39,16 +39,22 @@
  * @file sipwitch/mapped.h
  */
 
+// user and device properties...
+
 #define	USER_PROFILE_DIALABLE		0x0001	// user may be dialed
 #define	USER_PROFILE_REACHABLE		0x0002	// user may be reached by gateway
 #define	USER_PROFILE_INTERNAL		0x0008	// user may use dialing/routing
 #define	USER_PROFILE_SUBSCRIPTIONS	0x0010	// user can subscribe to others
 #define	USER_PROFILE_SUBSCRIBERS	0x0020	// user can be subscribed
-#define	USER_PROFILE_MULTITARGET	0x0800	// multi-target registration
 #define	USER_PROFILE_INCOMING		0x1000  // user "name" id may be accessed
 #define	USER_PROFILE_OUTGOING		0x2000	// may use generic uri
+#define	USER_PROFILE_SUPERUSER		0x8000	// has admin flag
 
-#define	USER_PROFILE_DEFAULT		0x0fff
+#define	USER_PROFILE_ADMIN			0xffff
+#define USER_PROFILE_LOCAL			0x0fff
+#define USER_PROFILE_DEVICE			0x0f0f
+#define	USER_PROFILE_SERVICE		0xff0f
+#define	USER_PROFILE_DEFAULT		0x7fff
 #define	USER_PROFILE_RESTRICTED	(0)
 
 #define	MAX_NETWORK_SIZE	16		// based on cidr name size...
@@ -102,6 +108,18 @@ public:
 			LinkedObject *routes;	// active route records
 		} internal;
 	};
+
+	inline bool isUser(void) const
+		{return (type == USER);};
+
+	inline bool isProfiled(void) const
+		{return (type == USER || type == SERVICE);};
+
+	inline bool isAdmin(void) const
+		{return (isProfiled() && (profile.features & USER_PROFILE_SUPERUSER));};
+
+	inline bool isFeature(unsigned short X) const
+		{return isProfiled() && (profile.features & X);};
 };
 
 class __EXPORT MappedCall : public LinkedObject
