@@ -457,6 +457,10 @@ private:
 	void dump(FILE *fp);
 
 public:
+	static unsigned uid;
+	static const char *sipusers;
+	static const char *sipadmin;
+
 	server(const char *id);
 
 	static bool check(void);
@@ -490,6 +494,7 @@ public:
 	static MappedRegistry *accept(const char *request);
 	static const char *referLocal(MappedRegistry *rr, const char *target, char *buffer, size_t size);
 	static const char *referRemote(MappedRegistry *rr, const char *target, char *buffer, size_t size);
+	static bool checkId(const char *id);
 };
 
 class __LOCAL messages : public service::callback
